@@ -1,18 +1,48 @@
 #!/usr/bin/env perl
+#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+#             Genome2Shooting
+#
+#     Copyright (C) 2001-2007 Keio University
+#:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+#
+#   $Id: G.pm,v 1.58 2001/11/23 03:43:18 t98901ka Exp $
+#
+# G-language System is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public
+# License as published by the Free Software Foundation; either
+# version 2 of the License, or (at your option) any later version.
+#
+# G-language System is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public
+# License along with G-language System -- see the file COPYING.
+# If not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+#
+#END_HEADER
+#
+# written by Kazuharu Arakawa <gaou@g-language.org> at
+# G-language Project, Institute for Advanced Biosciences, Keio University.
+#
 
 use G;
+use File::ShareDir ':ALL';
 use Getopt::Long;
 
 my ($speed);
-my $filename = $ARGV[0] ||= 'NC_000908';
+my $sharedir = dist_dir('g-language');
+my $filename = $ARGV[0] ||= "$sharedir/genomes/buchnera.gbk";
 GetOptions("ptt=s"=>\$ptt, "speed=s"=>\$speed);
-$ptt = '' unless($ptt);
+$ptt = "$sharedir/genomes/buchnera.ptt" unless($ptt);
 
 my $gb = new G($ARGV[0], "no msg");
 set_gpac($gb, -ptt=>$ptt);
 cai($gb, -output=>"NULL", -filename=>"/dev/null");
 
-my $BitMapPath = "/usr/local/g-language/g2s";
+my $BitMapPath = "$sharedir/g2s";
 
 my %main = (
 	    width=>600, height=>600, x=>190, y=>500, jx=>34, jy=>34,
@@ -160,6 +190,8 @@ use Wx::Event qw(EVT_KEY_UP EVT_KEY_DOWN EVT_TIMER EVT_PAINT);
 
 @ISA = qw(Wx::ScrolledWindow);
 
+my $len = length $gb->{SEQ};
+
 sub new {
     my ($class, $frame) = @_;
     my $this = $class->SUPER::new($frame,-1,wxDefaultPosition, wxDefaultSize, wxCLIP_CHILDREN);
@@ -223,7 +255,8 @@ sub OnTimer{
 	$main{energy}->Refresh();
     }
 
-    $main{counter}->SetLabel($main{time} * $main{speed}) unless ($main{time} * $main{speed}>= length $gb->{SEQ});
+    $main{counter}->SetLabel($main{time} * $main{speed}) 
+	unless ($main{time} * $main{speed}>= $len);
 
     if (scalar(@cds) == 0){
 	$main{gene}->SetLabel("no more genes");
@@ -284,7 +317,7 @@ sub OnTimer{
 	    if ($bulletobj->move()){
 		push(@newbullet, $bulletobj);
 	    }else{
-		$bulletobj->{obj}->Destroy();
+#		$bulletobj->DESTROY();
 		undef $bulletobj;
 	    }
 	}
@@ -297,7 +330,7 @@ sub OnTimer{
 	    if ($waveobj->move()){
 		push(@newwave, $waveobj);
 	    }else{
-		$waveobj->{obj}->Destroy();
+#		$waveobj->{obj}->Destroy();
 		undef $waveobj;
 	    }
 	}
@@ -310,7 +343,7 @@ sub OnTimer{
 	    if ($laserobj->move()){
 		push(@newlaser, $laserobj);
 	    }else{
-		$laserobj->{obj}->Destroy();
+#		$laserobj->DESTROY();
 		undef $laserobj;
 	    }
 	}
@@ -323,7 +356,7 @@ sub OnTimer{
 	    if ($itemobj->move()){
 		push(@newitem, $itemobj);
 	    }else{
-		$itemobj->{obj}->Destroy();
+#		$itemobj->{obj}->Destroy();
 		undef $itemobj;
 	    }
 	}
@@ -337,7 +370,7 @@ sub OnTimer{
 		$enemobj->{hit} --;
 
 		if ($enemobj->{hit} == 0){
-		    $enemobj->{obj}->Destroy();
+#		    $enemobj->{obj}->Destroy();
 		    undef $enemobj;
 		}else{
 		    if ($enemobj->{hit} == 1){
@@ -354,7 +387,7 @@ sub OnTimer{
 	    }
 	}
 	@enemy = @newenemy;
-    }elsif(scalar(@enemy) < 1 && $main{time} * $main{speed} >= length $gb->{SEQ}){
+    }elsif(scalar(@enemy) < 1 && $main{time} * $main{speed} >= $len){
 	unless($main{clear}){
 	    $main{congrate} = Wx::StaticBitmap->new( $this, -1, $main{congrat}, [55, 190]);
 	    $main{completede} = Wx::StaticBitmap->new( $this, -1, $main{completed}, [35, 280]);	
@@ -410,6 +443,9 @@ sub OnKeyDown{
     }elsif ($event->GetKeyCode() == 306 && $main{power} >= 200){
 	push(@wave, StgWave->new($this));
 	$main{power} -= 200;
+	if($main{power} < 0){
+	    $main{power} = 0;
+	}
     }elsif ($event->GetKeyCode() == 80){
 	if ($pause){
 	    $pause = 0;
@@ -686,6 +722,7 @@ my %COGnum = (
                  C=>4,        G=>4,         E=>4,
 	         F=>4,        H=>4,         I=>4,
                  Q=>4,        R=>5,         S=>5,
+	         U=>5,
                  '-'=>5,
                  );
 
@@ -701,6 +738,9 @@ sub new {
     $this->{panel} = $panel;
     $this->{cai} = $gb->{$cds}->{cai} ** 10;
     $this->{id} = $COGnum{$gb->{$cds}->{code}};
+    unless(length $this->{id}){
+	$this->{id} = 5;
+    }
     $this->{obj} = Wx::StaticBitmap->new( $panel, -1, $main{bullet}, $this->{pos});
 
     return bless $this;
@@ -803,7 +843,7 @@ sub hantei{
 
 sub player_hit{
     $main{playerhit} = 4;
-    $main{bmp}->SetBitmap($main{bomb3});
+#    $main{bmp}->SetBitmap($main{bomb3});
     $main{life} -- unless($main{life} == 0);;
     $main{gauge}->SetValue($main{life});
     $main{gauge}->Refresh();
