@@ -50,9 +50,10 @@ require G::IO::FastaI;
 require G::IO::EmblI;
 
 use File::Basename;
+use File::ShareDir ':ALL';
 
 our @ISA = qw(G::Prelude G::IO::GenBankI G::IO::GenBankO);
-our $VERSION = '1.6.13';
+our $VERSION = '1.7.0';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -60,7 +61,7 @@ our $VERSION = '1.6.13';
 
 =head1 NAME
 
-G::Skyline
+G::Skyline - G-language v.2 core class
 
 =head1 SYNOPSIS
 
@@ -86,6 +87,7 @@ Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 my $outfile = '';
 my $loaded = 0;
 my $infile = '';
+my $sharedir = dist_dir('g-language');
 
 #::::::::::::::::::::::::::::::
 #    Let the code begin...
@@ -94,6 +96,20 @@ my $infile = '';
 sub new {
     my $pkg = shift;
     my $filename = shift;
+
+    if(length($filename) < 1){
+	$filename = "$sharedir/genomes/ecoli.gbk";
+	msg_error("WARNING: no genome file specified. Loading Escherichia coli K12 MG1655 genome as a sample.\n");
+    }elsif(
+	   $filename eq 'ecoli' || 
+	   $filename eq 'bsub' || 
+	   $filename eq 'pyro' || 
+	   $filename eq 'mgen' || 
+	   $filename eq 'cyano'
+	   ){
+	$filename = "$sharedir/genomes/$filename.gbk";
+    }
+
     my @options = @_;
     my $this = {};
     my $tmp = {};
